.. _expression_api_toplevel:

SQL Statements and Expressions API
==================================

.. module:: sqlalchemy.sql.expression

This section presents the API reference for the SQL Expression Language.  For a full introduction to its usage,
see :ref:`sqlexpression_toplevel`.


.. toctree::
    :maxdepth: 3

    sqlelement
    operators
    selectable
    dml
    functions
    compiler
    serializer
    visitors
